<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.0">
<context>
    <name>RazorCpuLoad</name>
    <message>
        <source>CPU load %1%</source>
        <translation>CPU負荷 %1%</translation>
    </message>
</context>
<context>
    <name>RazorCpuLoadConfiguration</name>
    <message>
        <source>Razor CPU Load settings</source>
        <translation>Razor CPU負荷設定</translation>
    </message>
    <message>
        <source>General</source>
        <translation>全般</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation>テキストを表示</translation>
    </message>
    <message>
        <source>Update interval:</source>
        <translation>更新周期:</translation>
    </message>
    <message>
        <source>sec</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Bar orientation:</source>
        <translation>棒グラフの方向:</translation>
    </message>
    <message>
        <source>Bottom up</source>
        <translation>下から上</translation>
    </message>
    <message>
        <source>Top down</source>
        <translation>上から下</translation>
    </message>
    <message>
        <source>Left to right</source>
        <translation>左から右</translation>
    </message>
    <message>
        <source>Right to left</source>
        <translation>右から左</translation>
    </message>
</context>
</TS>